code cleanup - remove unused hipstream from the RocDecoder class (#155)

[ROCm/rocdecode commit: 224e98ab2d]
This commit is contained in:
Aryan Salmanpour
2024-01-08 14:54:28 -05:00
committed by GitHub
szülő af09e155f8
commit adb35c9fa5
2 fájl változott, egészen pontosan 1 új sor hozzáadva és 11 régi sor törölve
@@ -25,15 +25,7 @@ THE SOFTWARE.
RocDecoder::RocDecoder(RocDecoderCreateInfo& decoder_create_info): va_video_decoder_{decoder_create_info}, decoder_create_info_{decoder_create_info} {}
RocDecoder::~RocDecoder() {
hipError_t hipStatus = hipSuccess;
if (hip_stream_) {
hipStatus = hipStreamDestroy(hip_stream_);
if (hipStatus != hipSuccess) {
ERR("ERROR: hipStreamDestroy failed! with hipStatus# " + TOSTR(hipStatus));
}
}
}
RocDecoder::~RocDecoder() {}
rocDecStatus RocDecoder::InitializeDecoder() {
rocDecStatus rocdec_status = ROCDEC_SUCCESS;
@@ -149,7 +141,6 @@ rocDecStatus RocDecoder::InitHIP(int device_id) {
}
CHECK_HIP(hipSetDevice(device_id));
CHECK_HIP(hipGetDeviceProperties(&hip_dev_prop_, device_id));
CHECK_HIP(hipStreamCreate(&hip_stream_));
return ROCDEC_SUCCESS;
}
@@ -59,6 +59,5 @@ private:
RocDecoderCreateInfo decoder_create_info_;
VaapiVideoDecoder va_video_decoder_;
hipDeviceProp_t hip_dev_prop_;
hipStream_t hip_stream_;
std::vector<hipExternalMemory_t> hip_ext_mem_;
};